<template>
  <div class="container pb-5 mb-5" v-if="data.loaded">
    <div class="card border-0 overflow-hidden">


      <!-- Image -->
      <img
          :src="data.advertise.image"
          class="img-fluid rounded-3 shadow-sm object-fit-cover w-100"
          alt="ad preview"
      />

      <!-- Info -->
      <div class="p-4 text-end">
        <h5 class="fw-bold">{{ data.advertise.title }}</h5>
        <p class="text-muted small mb-2">{{ data.advertise.date }} در {{ data.advertise.province?.title }}،
          {{ data.advertise.city?.title }}</p>
        <p class="fw-bold fs-5">{{
            data.advertise.price == 0 ? t('advertise_show.price_agreement') : $helper.getCurrency(data.advertise.price) + ' تومان'
          }}</p>
        <span class="status-badge bg-secondary-light font-size-10 text-secondary py-0">
                  <i class="icon icon-regular-clock text-secondary font-size-16 mt-1 ms-1"></i>
                  {{ data.advertise.step.title }}
                </span>
      </div>


      <!-- Action Buttons -->
      <div class="p-3">
        <div class="row g-2">
          <div class="col-6">
            <nuxt-link :to="'/ads/' + data.advertise.slug" class="btn btn-success w-100 py-2 rounded-3">
              <i class="icon icon-regular-eye ms-2 text-white"></i> {{ t('advertise_show.view') }}
            </nuxt-link>
          </div>
          <div class="col-6">
            <nuxt-link :to="'/account/advertise/edit/' + data.advertise.id"
                       class="btn btn-info w-100 py-2 text-white rounded-3">
              <i class="icon icon-regular-edit ms-2 text-white"></i> {{ t('advertise_show.edit') }}
            </nuxt-link>
          </div>
          <div class="col-6">
            <nuxt-link :to="'/account/advertise/stats/' + data.advertise.id" class="btn btn-secondary w-100 py-2 rounded-3">
              <i class="icon icon-regular-chart-line ms-2 text-white"></i> {{ t('advertise_show.stats') }}
            </nuxt-link>
          </div>
          <div class="col-6">
            <nuxt-link :to="'/account/advertise/upgrade/' + data.advertise.id"
                       class="btn btn-warning w-100 py-2 text-white rounded-3">
              <i class="icon icon-regular-arrow-up ms-2 text-white"></i> {{ t('advertise_show.upgrade') }}
            </nuxt-link>
          </div>
          <div class="col-6">
            <button class="btn btn-danger w-100 py-2 rounded-3" @click="removeAdvertise">
              <i class="icon icon-regular-trash ms-2 text-white"></i> {{ t('advertise_show.delete') }}
            </button>
          </div>
          <div class="col-6">
            <nuxt-link :to="'/account/advertise/story/' + data.advertise.id"
                       class="btn btn-default w-100 py-2 text-white rounded-3">
              <i class="icon icon-regular-story ms-2 text-white"></i> {{ t('advertise_show.story_list') }}
            </nuxt-link>
          </div>
        </div>
      </div>
    </div>
  </div>
  <div v-else class="text-center text-muted py-5">{{ t('advertise_show.loading') }}</div>
</template>

<script setup>
import {ref, onMounted, reactive} from 'vue'
import {useRoute, useRouter} from "vue-router";
import {useCookie} from "nuxt/app";
import {useI18n} from 'vue-i18n'

const {t} = useI18n()

// Variable
const route = useRoute()
const router = useRouter()
const {$api, $sweetalert, $helper} = useNuxtApp()

const data = reactive({
  loaded: false,
  advertise: {}
})

const getData = async () => {
  data.loaded = false;
  await $api.post('/user/advertise/show', {
    id: route.params.id
  }).then((value) => {
    data.advertise = value.data.data;

    setTimeout(() => {
      data.loaded = true;
    },500)
  })
}

const removeAdvertise = async () => {
  await $sweetalert.confirm(async () => {
    await $api.post('/user/advertise/delete', {
      id: route.params.id
    }, {
      headers: {
        Authorization: `Bearer ${useCookie('token').value}`
      }
    }).then((value) => {
      if (value.data.status) {
        $sweetalert.success(t('advertise_show.delete_success'))
        router.push('/account/advertise') // هدایت به لیست آگهی‌ها
      }
    })
  })
}

onMounted(() => {
  getData();
});

</script>

<style scoped>

</style>